@@ -1,13 +1,9 @@
-use glib::{object::IsA, translate::*};
+use glib::translate::*;
 use gst::prelude::*;
 
-use crate::auto::AudioAggregatorPad;
+use crate::{ffi, AudioAggregatorPad};
 
-pub trait AudioAggregatorPadExtManual: 'static {
-    fn audio_info(&self) -> Option<crate::AudioInfo>;
-}
-
-impl<O: IsA<AudioAggregatorPad>> AudioAggregatorPadExtManual for O {
+pub trait AudioAggregatorPadExtManual: IsA<AudioAggregatorPad> + 'static {
     fn audio_info(&self) -> Option<crate::AudioInfo> {
         unsafe {
             let ptr = self.as_ptr() as *mut ffi::GstAudioAggregatorPad;
@@ -25,3 +21,5 @@ impl<O: IsA<AudioAggregatorPad>> AudioAggregatorPadExtManual for O {
         }
     }
 }
+
+impl<O: IsA<AudioAggregatorPad>> AudioAggregatorPadExtManual for O {}
